@@ -91,7 +91,6 @@ class GoaLastFM(GObject.GObject):
         self.disabled = klass.props.music_disabled
 
     @GObject.Property(type=bool, default=True)
-    @log
     def disabled(self):
         """Retrieve the disabled status for the Last.fm account
 
@@ -101,7 +100,6 @@ class GoaLastFM(GObject.GObject):
         return self._disabled
 
     @disabled.setter
-    @log
     def disabled(self, value):
         """Set the disabled status for the Last.fm account
 
@@ -110,19 +108,16 @@ class GoaLastFM(GObject.GObject):
         self._disabled = value
 
     @GObject.Property
-    @log
     def secret(self):
         """Retrieve the Last.fm client secret"""
         return self._authentication.props.client_secret
 
     @GObject.Property
-    @log
     def client_id(self):
         """Retrieve the Last.fm client id"""
         return self._authentication.props.client_id
 
     @GObject.Property
-    @log
     def session_key(self):
         """Retrieve the Last.fm session key"""
         return self._authentication.call_get_access_token_sync(None)[0]
@@ -216,12 +211,12 @@ class LastFmScrobbler(GObject.GObject):
             logger.warning(msg.props.response_body.data)
 
     @log
-    def scrobble(self, media, time_stamp):
+    def scrobble(self, coresong, time_stamp):
         """Scrobble a song to Last.fm.
 
         If not connected to Last.fm nothing happens
 
-        :param media: Grilo media item
+        :param coresong: CoreSong to scrobble
         :param time_stamp: song loaded time (epoch time)
         """
         self.scrobbled = True
@@ -229,19 +224,21 @@ class LastFmScrobbler(GObject.GObject):
         if self._goa_lastfm.disabled:
             return
 
+        media = coresong.props.media
         self._lastfm_api_call(media, time_stamp, "scrobble")
 
     @log
-    def now_playing(self, media):
+    def now_playing(self, coresong):
         """Set now playing song to Last.fm
 
         If not connected to Last.fm nothing happens
 
-        :param media: Grilo media item
+        :param coresong: CoreSong to use for now playing
         """
         self.scrobbled = False
 
         if self._goa_lastfm.disabled:
             return
 
+        media = coresong.props.media
         self._lastfm_api_call(media, None, "update now playing")
